import { dataSource } from "../../data-source";
import { webapiPermission } from "../../entity/user/webapi_permission";
import InternalException from "../../exceptions/internalException";

export default abstract class WebapiPermissionService {
  /**
   * @description get permission by api
   * @param webapiId number
   * @returns {Promise<Array<webapiPermission>>}
   */
  static async getByApi(webapiId: number): Promise<Array<webapiPermission>> {
    return await dataSource
      .getRepository(webapiPermission)
      .createQueryBuilder("api_permission")
      .where("api_permission.apiId = :apiId", { apiId: webapiId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("api permissions not found by api", err);
      });
  }
}
